
from __future__ import print_function, unicode_literals, absolute_import, division
from reahl.doc.examples.tutorial.helloapache.helloapache import HelloUI

web.site_root = HelloUI
